<?php
if (!defined('DC_CONTEXT_ADMIN')) { return; }

dcCore::app()->addBehavior('adminPostFormSidebar', array('shortURLBehaviors','shortURLDisplay'));
dcCore::app()->addBehavior('adminAfterCommentDesc', array('shortURLBehaviors','shortCommentURLDisplay'));
if (dcCore::app()->plugins->moduleExists('pages')) {
    dcCore::app()->addBehavior('adminPageFormSidebar', array('shortURLBehaviors','shortURLDisplay'));
}
if (dcCore::app()->plugins->moduleExists('gallery')) {
    dcCore::app()->addBehavior('adminGalleryFormSidebar', array('shortURLBehaviors','shortURLDisplay'));
    dcCore::app()->addBehavior('adminGalleryItemFormSidebar', array('shortURLBehaviors','shortURLDisplay'));
}

dcCore::app()->addBehavior('adminBlogPreferencesFormV2', array('shortURLBehaviors', 'adminBlogPreferencesForm'));
dcCore::app()->addBehavior('adminBeforeBlogSettingsUpdate', array('shortURLBehaviors', 'adminBeforeBlogSettingsUpdate'));

# BEHAVIORS
class shortURLBehaviors
{
    public static function shortURLDisplay(dcRecord $post = null)
    {
        if ($post && dcCore::app()->blog->settings->shortURL->shortURLEnabled) {
            $id = dcShortURL::idConversion($post->post_id);
            $url = dcCore::app()->blog->url.dcCore::app()->url->getBase('shortURL').'/'.$id;
            echo '<div id="shurl-box" class="sb-box"><h4>'.__('Short URL').'</h4><p><a href="'.$url.'">'.$url.'</a></p></div>';
        }
    }

    public static function shortCommentURLDisplay(dcRecord $comment = NULL)
    {
        if ($comment && dcCore::app()->blog->settings->shortURL->shortURLEnabled) {
            $id = dcShortURL::idConversion($comment->comment_id);
            $url = dcCore::app()->blog->url.dcCore::app()->url->getBase('shortURLComment').'/'.$id;
            return '<p>'.__('Short URL:').' <a href="'.$url.'">'.$url.'</a></p>';
        }
    }

    public static function adminBlogPreferencesForm(dcSettings $settings)
    {
        $activate = $settings->shortURL->shortURLEnabled ? true : false;
        $prefix = $settings->shortURL->shortURLPrefix;
        $commentPrefix = $settings->shortURL->shortURLCommentPrefix;
        $backCompatibility = $settings->shortURL->shortURLBackCompatibility ? true : false;
        $evenShorter = $settings->shortURL->shortURLEvenShorter ? true : false;

        echo "<div class=\"fieldset\" id=\"shortURL\"><h4>".__('Short URLs')."</h4>\n";
        echo "<p><label class=\"classic\">".form::checkbox('enableShortURL', '1', $activate)."\n".
            __('Enable short URL system.')."</label></p>\n";
        echo "<p><label class=\"classic\">".__('Prefix to use in short URLs:')."\n".
            form::field('shortURLPrefix', 10, 20, $prefix)."</label></p>\n";
        echo "<p><label class=\"classic\">".__('Prefix to use in short URLs for comments:')."\n".
            form::field('shortURLCommentPrefix', 10, 20,$commentPrefix)."</label></p>\n";
        echo "<p><label class=\"classic\">".form::checkbox('evenShorterURL', '1', $evenShorter)."\n".
            __('Use even shorter URLs than the post/comment id.')."</label></p>\n";
        echo "<p><label class=\"classic\">".form::checkbox('backCompatibleShortURL', '1', $backCompatibility)."\n".
            __('Provide backwards compatibility (ie, support postid type URL).')."</label></p>\n";
        echo "</div>\n";
    }

    public static function adminBeforeBlogSettingsUpdate(dcSettings $settings)
    {
        $enabled = empty($_POST['enableShortURL']) ? false : true;
        $backCompatibility = empty($_POST['backCompatibleShortURL']) ? false : true;
        $evenShorter = empty($_POST['evenShorterURL']) ? false : true;
        $prefix = empty($_POST['shortURLPrefix']) ? 'shurl' : $_POST['shortURLPrefix'];
        $commentPrefix = empty($_POST['shortURLCommentPrefix']) ? 'shurlc' : $_POST['shortURLCommentPrefix'];

        $settings->addNamespace('shortURL');
        $settings->shortURL->put(
            'shortURLEnabled',
            $enabled,
            'boolean',
            'Enable short URL system');
        $settings->shortURL->put(
            'shortURLPrefix',
            $prefix,
            'string',
            'Short URL system prefix');
        $settings->shortURL->put(
            'shortURLCommentPrefix',
            $commentPrefix,
            'string',
            'Short URL system prefix for comments');
        $settings->shortURL->put(
            'shortURLBackCompatibility',
            $backCompatibility,
            'boolean',
            'Still support the old URL system (ie the \'postid\' prefix)');
        $settings->shortURL->put(
            'shortURLEvenShorter',
            $evenShorter,
            'boolean',
            'Use even shorter URLs');
    }

}
