<?php
/**
 * @brief shortURL, a plugin for Dotclear 2
 *
 * @package Dotclear
 * @subpackage Plugins
 *
 * @author julien mudry and contributors
 *
 * @copyright julien mudry
 * @copyright GPL-2.0 https://www.gnu.org/licenses/gpl-2.0.html
 */
if (!defined('DC_CONTEXT_ADMIN')) {
    return;
}

if (!dcCore::app()->newVersion(basename(__DIR__), dcCore::app()->plugins->moduleInfo(basename(__DIR__), 'version'))) {
    return;
}

function putShurlGlobalSetting($id, $value, $type=null, $label=null, $valueChange=true)
{
    $oldValue = dcCore::app()->blog->settings->shortURL->get($id);
    if ($oldValue === null) {
        dcCore::app()->blog->settings->shortURL->put($id, $value, $type, $label, $valueChange, true);
    } else {
        dcCore::app()->blog->settings->shortURL->put($id, $old_value, $type, $label, $valueChange, true);
    }
}

try {
    // Insert below necessary initialisations and updates

    dcCore::app()->blog->settings->addNamespace('shortURL');
    putShurlGlobalSetting('shortURLEnabled', false, 'boolean', 'Enable short URL system');
    putShurlGlobalSetting('shortURLPrefix', 'shurl', 'string', 'Short URL system prefix');
    putShurlGlobalSetting('shortURLCommentPrefix', 'shurlc', 'string', 'Short URL system prefix for comments');
    putShurlGlobalSetting('shortURLBackCompatibility', false, 'boolean', 'Still support the old URL system (ie the \'postid\' prefix)');

    $old_version = dcCore::app()->getVersion(basename(__DIR__));
    if (version_compare((string) $old_version, '0.6.0', '<')) {

        ; // Update since 0.6.0 to be completed

    }

    return true;
} catch (Exception $e) {
    dcCore::app()->error->add($e->getMessage());
}

return false;
